import{P as r}from"./Passwordless.b773d311.js";import{N as a}from"./Navbar.6ffc0ef7.js";import{d,b as i,c,e as t,H as p,q as _}from"./registerWidgets.358232d6.js";import{M as m}from"./member.1f409183.js";import"./CircularLoading.66cf5ef8.js";import"./lottie.fbc237c8.js";import"./icons.c4e80053.js";import"./passwordlessManager.5093fac0.js";import"./pubsub.5d0401cb.js";import"./logo.084e5d7c.js";import"./asyncComputed.c8d50303.js";import"./gateway.a5838eb2.js";import"./activeRecord.360f8d7f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="63cb196f-5c65-4fe7-a3a1-da303db1d55b",e._sentryDebugIdIdentifier="sentry-dbid-63cb196f-5c65-4fe7-a3a1-da303db1d55b")}catch{}})();const f={class:"login"},b=d({__name:"Login",setup(e){const o=p();async function s(n){await m.login(),o.push({name:"home"})}return(n,l)=>(i(),c("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const B=_(b,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.a9667774.js.map
