.error[data-v-d3846761]{display:flex;flex-direction:column;align-items:center;justify-content:center;width:100%;height:100%;background-color:#f5f5f5}.error-header[data-v-d3846761]{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100px;width:100%;box-sizing:border-box}.error-body[data-v-d3846761],.error-message[data-v-d3846761],.error-actions[data-v-d3846761]{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100%;width:100%;box-sizing:border-box}.error-details[data-v-d3846761]{padding:1rem;color:red;border:1px solid red;background-color:#fff;border-radius:5px}
