import{M as r}from"./Modal.a3024ac1.js";import{d as a,v as c,r as d,b as _,c as f,e as n,w as l,F as i,a as b,x as m,q as u}from"./registerWidgets.358232d6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b102bfbf-01a6-4208-8241-1b3754aed46e",e._sentryDebugIdIdentifier="sentry-dbid-b102bfbf-01a6-4208-8241-1b3754aed46e")}catch{}})();const p=["src"],y=a({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=b("router-view");return _(),f(i,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:l(()=>[m("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const I=u(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.c4c53f79.js.map
