import{d as o,b as c,c as d,q as a}from"./registerWidgets.358232d6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9283d4e3-4bad-454a-a166-88fe3fcdcd13",e._sentryDebugIdIdentifier="sentry-dbid-9283d4e3-4bad-454a-a166-88fe3fcdcd13")}catch{}})();const _=["href"],r=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),d("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,_)}}});const u=a(r,[["__scopeId","data-v-9fec5678"]]);export{u as D};
//# sourceMappingURL=DocsButton.075983eb.js.map
