import{q as o,a as r,b as i,t as c,f as p,g as d,_,h as u,k as l,T as f,P as h,C as g,M as y,s as m,i as b,j as s,l as v,m as w,n as k}from"./registerWidgets.358232d6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c914632a-da26-479c-a0c1-60774fa01bf6",e._sentryDebugIdIdentifier="sentry-dbid-c914632a-da26-479c-a0c1-60774fa01bf6")}catch{}})();const I={};function A(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",A]]),a=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.e92a7a89.js"),["assets/Player.e92a7a89.js","assets/index.f504f95d.js","assets/registerWidgets.358232d6.js","assets/registerWidgets.448db7e9.css","assets/uuid.8407adc0.js","assets/broker.2c645842.js","assets/passwordlessManager.5093fac0.js","assets/pubsub.5d0401cb.js","assets/icons.c4e80053.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.7e7bf4fe.js","assets/Passwordless.b773d311.js","assets/CircularLoading.66cf5ef8.js","assets/lottie.fbc237c8.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.86ac0c56.css","assets/executeJs.ee77da09.js","assets/PlayerNavbar.d4b69fb4.js","assets/PlayerNavbar.adff8b48.css","assets/WidgetsFrame.578f4bff.js","assets/colors.58e6e833.js","assets/WidgetsFrame.701a818b.css","assets/Modal.a3024ac1.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/broker.5f3abad8.css","assets/DashPlayer.3416870d.js","assets/runnerData.32f36cf2.js","assets/DashPlayer.ef4a798d.css","assets/asyncComputed.c8d50303.js","assets/Player.20a058fa.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});f.init(),D.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,a),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.4d1b0a71.js.map
