import{q as t,b as s,c as a}from"./registerWidgets.358232d6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="ab26fd3a-23a7-4cfb-aecf-8b33e247f51c",e._sentryDebugIdIdentifier="sentry-dbid-ab26fd3a-23a7-4cfb-aecf-8b33e247f51c")}catch{}})();const c={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const d=t(c,[["render",r]]);export{d as default};
//# sourceMappingURL=OrganizationSettings.9fe67d9b.js.map
