import{d as u,K as m,b as _,t as b,w as f,z as i,J as y,O as g,Q as h,x as d,U as n,q as w}from"./registerWidgets.358232d6.js";import{a as I}from"./asyncComputed.c8d50303.js";import"./gateway.a5838eb2.js";import{B as x}from"./build.d02345da.js";import"./index.2e4d6ec7.js";import{C as v}from"./CrudView.42bcc5b6.js";import"./passwordlessManager.5093fac0.js";import"./pubsub.5d0401cb.js";import"./activeRecord.360f8d7f.js";import"./DropdownMenu.47ef3fba.js";import"./Modal.a3024ac1.js";import"./LoadingIndicator.7cda47d1.js";import"./lottie.fbc237c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f8725ab4-b5f2-4e24-82b5-4ec2305cb336",e._sentryDebugIdIdentifier="sentry-dbid-f8725ab4-b5f2-4e24-82b5-4ec2305cb336")}catch{}})();const B=e=>(g("data-v-1b7a68a8"),e=e(),h(),e),C=B(()=>d("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),d("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),S=u({__name:"Builds",setup(e){const r=y().params.projectId,{loading:c,result:p}=I(()=>x.list(r)),l=m(()=>{var s,a;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(a=(s=p.value)==null?void 0:s.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?a:[]}});return(s,a)=>(_(),b(v,{"entity-name":"build",loading:i(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:i(l)},{"empty-description":f(()=>[C]),_:1},8,["loading","table"]))}});const L=w(S,[["__scopeId","data-v-1b7a68a8"]]);export{L as default};
//# sourceMappingURL=Builds.464c8148.js.map
