import{t as c}from"./icons.c4e80053.js";import{d,J as u,H as i,a as p,b as _,c as l,e as f,z as m,U as b,q as y}from"./registerWidgets.358232d6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ddadff78-490d-43fe-8a82-c2a4ebaac0ae",e._sentryDebugIdIdentifier="sentry-dbid-ddadff78-490d-43fe-8a82-c2a4ebaac0ae")}catch{}})();const v=d({__name:"PreviewButton",props:{model:null},setup(e){const t=e,o=u(),a=i(),s=()=>{const n=o.query;a.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const r=p("icon");return _(),l("button",{class:"preview-button",onClick:s},[f(r,{class:"icon",path:m(c),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),b(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.b964a8cd.js.map
