import{d as u,K as b,b as y,t as g,z as s,J as _}from"./registerWidgets.358232d6.js";import{a as w}from"./asyncComputed.c8d50303.js";import"./gateway.a5838eb2.js";import{M as i}from"./member.1f409183.js";import"./index.2e4d6ec7.js";import{C as I}from"./CrudView.42bcc5b6.js";import"./passwordlessManager.5093fac0.js";import"./pubsub.5d0401cb.js";import"./activeRecord.360f8d7f.js";import"./DropdownMenu.47ef3fba.js";import"./Modal.a3024ac1.js";import"./LoadingIndicator.7cda47d1.js";import"./lottie.fbc237c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="29f05807-46a5-4849-8480-073e03621f6f",e._sentryDebugIdIdentifier="sentry-dbid-29f05807-46a5-4849-8480-073e03621f6f")}catch{}})();const K=u({__name:"Members",setup(e){const a=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(a,t.email),p()},{loading:d,result:c,refetch:p}=w(()=>i.list(a)),f=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(f),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Members.118d9697.js.map
