import{d as b,K as i,b as _,c as g,e as s,z as c,x as l,F as v,J as f,a as y,q as h}from"./registerWidgets.358232d6.js";import{a as p}from"./asyncComputed.c8d50303.js";import{P as I}from"./project.2d38ef8a.js";import"./gateway.a5838eb2.js";import{O as j}from"./organization.a6c74922.js";import"./index.2e4d6ec7.js";import{N as z}from"./Navbar.6ffc0ef7.js";import{S as w}from"./Sidebar.0bf42408.js";import{H as P,I as k,D as x,J as B,K as D,L as $,E as C,F as E,G as N}from"./icons.c4e80053.js";import"./activeRecord.360f8d7f.js";import"./pubsub.5d0401cb.js";import"./passwordlessManager.5093fac0.js";import"./logo.084e5d7c.js";import"./Tooltip.e20bc775.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[o]="b15c0150-6bfb-49b7-805b-3d8b9ed375e9",a._sentryDebugIdIdentifier="sentry-dbid-b15c0150-6bfb-49b7-805b-3d8b9ed375e9")}catch{}})();const S={class:"project"},F={class:"content-wrapper"},K=b({__name:"Project",setup(a){const r=f().params.projectId,{result:e}=p(()=>I.get(r)),{result:t}=p(()=>e.value?j.get(e.value.organizationId):Promise.resolve(null)),m=i(()=>{var n;return t.value&&e.value?[{label:(n=t.value)==null?void 0:n.name,path:`/organizations/${t.value.id}`},{label:e.value.name,path:`/projects/${e.value.id}`}]:void 0}),d=i(()=>e.value?[{name:"Project",items:[{name:"Builds",path:"builds",icon:P},{name:"Connectors",path:"connectors",icon:k},{name:"API Keys",path:"api-keys",icon:x},{name:"Env Vars",path:"env-vars",icon:B},{name:"Logs",icon:D,path:"logs",beta:!0},{name:"Settings",icon:$,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:C,path:`/organizations/${e.value.organizationId}/projects`},{name:"Members",icon:E,path:`/organizations/${e.value.organizationId}/members`},{name:"Billing",icon:N,path:`/organizations/${e.value.organizationId}/billing`,unavailable:!0}]}]:[]);return(n,L)=>{const u=y("router-view");return _(),g(v,null,[s(z,{class:"nav",breadcrumb:c(m)},null,8,["breadcrumb"]),l("div",S,[s(w,{class:"sidebar",sections:c(d)},null,8,["sections"]),l("div",F,[s(u)])])],64)}}});const Y=h(K,[["__scopeId","data-v-f3927501"]]);export{Y as default};
//# sourceMappingURL=Project.60a18a1e.js.map
